@@ -3,8 +3,9 @@ import os
 
 
 class n_env:
-    __remote_api = "https://public.naas.ai/runner"
     _api = None
+    _version = None
+    _remote_mode = False
     _api_port = None
     _notif_api = None
     _proxy_api = None
@@ -17,6 +18,7 @@ class n_env:
     _user = None
     _tz = None
     _sentry_dsn = None
+    _scheduler = True
     _scheduler_interval = None
     _scheduler_job_max = None
     _scheduler_job_name = None
@@ -30,13 +32,29 @@ class n_env:
     def api_port(self, api_port: int):
         self._api_port = api_port
 
+    @property
+    def version(self):
+        return self._version
+
+    @version.setter
+    def version(self, version: str):
+        self._version = version
+
+    @property
+    def remote_mode(self):
+        return self._remote_mode
+
+    @remote_mode.setter
+    def remote_mode(self, remote_mode):
+        self._remote_mode = remote_mode
+
     @property
     def api(self):
         return self._api or os.environ.get(
             "NAAS_API",
-            f"http://localhost:{self._api_port}"
-            if self._api_port
-            else self.__remote_api,
+            f"http://localhost:{self.api_port}"
+            if not self.remote_mode
+            else self.remote_api,
         )
 
     @api.setter
@@ -87,6 +105,10 @@ class n_env:
     def shell_user(self, shell_user):
         self._shell_user = shell_user
 
+    @property
+    def remote_api(self):
+        return f"{self.proxy_api}/runner"
+
     @property
     def token(self):
         return self._token or os.environ.get("JUPYTERHUB_API_TOKEN", "")
@@ -119,6 +141,14 @@ class n_env:
     def sentry_dsn(self, sentry_dsn):
         self._sentry_dsn = sentry_dsn
 
+    @property
+    def scheduler(self):
+        return bool(self._scheduler)
+
+    @scheduler.setter
+    def scheduler(self, scheduler):
+        self._scheduler = bool(self._scheduler)
+
     @property
     def scheduler_interval(self):
         return int(
